==> skale.py-5.0.dev16-py3-none-any.whl: skale/contracts/manager/test/time_helpers_with_debug.py <==
#   -*- coding: utf-8 -*-
#
#   This file is part of SKALE.py
#
#   Copyright (C) 2020-Present SKALE Labs
#
#   SKALE.py is free software: you can redistribute it and/or modify
#   it under the terms of the GNU Affero General Public License as published by
#   the Free Software Foundation, either version 3 of the License, or
#   (at your option) any later version.
#
#   SKALE.py is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU Affero General Public License for more details.
#
#   You should have received a copy of the GNU Affero General Public License
#   along with SKALE.py.  If not, see <https://www.gnu.org/licenses/>.

from skale.contracts.base_contract import BaseContract, transaction_method
from skale.transactions.result import TxRes


class TimeHelpersWithDebug(BaseContract):
    """Wrapper for TimeHelpersWithDebug.sol functions (internal usage only)"""

    @transaction_method
    def skip_time(self, sec: int) -> TxRes:
        """Skip time on contracts

        :param sec: Time to skip in seconds
        :type sec: int
        :returns: Transaction results
        :rtype: TxRes
        """
        return self.contract.functions.skipTime(sec)

    def get_current_month(self) -> int:
        """Get current month from contract

        :returns: Month index
        :rtype: int
        """
        return self.contract.functions.getCurrentMonth().call()

==> skale.py-7.0.dev9-py3-none-any.whl: skale/contracts/manager/test/time_helpers_with_debug.py <==
#   -*- coding: utf-8 -*-
#
#   This file is part of SKALE.py
#
#   Copyright (C) 2020-Present SKALE Labs
#
#   SKALE.py is free software: you can redistribute it and/or modify
#   it under the terms of the GNU Affero General Public License as published by
#   the Free Software Foundation, either version 3 of the License, or
#   (at your option) any later version.
#
#   SKALE.py is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU Affero General Public License for more details.
#
#   You should have received a copy of the GNU Affero General Public License
#   along with SKALE.py.  If not, see <https://www.gnu.org/licenses/>.

from web3.contract.contract import ContractFunction

from skale.contracts.base_contract import transaction_method
from skale.contracts.skale_manager_contract import SkaleManagerContract


class TimeHelpersWithDebug(SkaleManagerContract):
    """Wrapper for TimeHelpersWithDebug.sol functions (internal usage only)"""

    @transaction_method
    def skip_time(self, sec: int) -> ContractFunction:
        """Skip time on contracts

        :param sec: Time to skip in seconds
        :type sec: int
        :returns: Transaction results
        :rtype: TxRes
        """
        return self.contract.functions.skipTime(sec)

    def get_current_month(self) -> int:
        """Get current month from contract

        :returns: Month index
        :rtype: int
        """
        return int(self.contract.functions.getCurrentMonth().call())
